import { Component, OnInit } from '@angular/core';
import {ChatMessage} from '../interfaces/chat-message';
import {isNumeric} from 'rxjs/internal-compatibility';
import {PythonBackendService} from "../core/python-backend.service";

@Component({
  selector: 'app-chatbot',
  templateUrl: './chatbot.page.html',
  styleUrls: ['./chatbot.page.scss'],
})
export class ChatbotPage implements OnInit {
  email = localStorage.getItem('email');
  chatMessages: ChatMessage[] = [];
  chatMessageInput = '';
  symptoms: string[] = ['anorexia','high fever','itching','pus discharge','fever','dripping urine','cough','vomiting','unable to swallowing','scratching','scratching the affected ear on the floor','blood in urine','eye discharge','lethargy','patchy hair loss','rubbing the affected ear on the floor','strain to urinate','nasal discharge','bloody diarrhea','increased salivation','crusty skin ulcers','frequently rotating movement','diarrhea','frequently urination','mild fever','drooling','skin redness','rash','painful','pale gums','licking genital area','abdominal pain','seizures','inflammation of skin','hyperemic gums','bloating','paralysis','unpleasant odor','redness on the ear','whining when urination','weight loss','hypersensitivity','stiff joints','muscle twitching','weakness','odd behavior','thickening of skin','abnormal bleeding','dehydration','sores on the abdomen','enlarged lymph nodes','sores on the legs','increased capillary refill time','difficulty breathing','sores on the ears','pain','sores on the chest','sores on the elbows','partial paralysis','complete paralysis'];
  symptomsItr: string[] = [];
  diseases: string[] = ['Canine Distemper','Canine Scabies','Otitis Media','Parvovirus ','Rabies','Tick Fever','Urinary tract infections (UTIs)'];
  inputArray = [[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]];

  age: number;
  breed: number;
  i = 0;

  public prediction: string;

  constructor(
    private pythonBackendService: PythonBackendService
  ) { }

  ngOnInit() {
    this.symptomsItr = this.symptoms;
    this.chatMessages.push({date: new Date(), message: 'Hi, '+this.email, user: false});
    this.chatMessages.push({date: new Date(), message: 'I am the virtual disease consultant of your dog\'s diseases. I can predict your dog\'s disease on behalf of you', user: false});
    this.chatMessages.push({date: new Date(), message: 'First, let me ask you a couple of questions about your dog to get to know your dog better', user: false});
    this.chatMessages.push({date: new Date(), message: 'Let’s Start by telling me about your dog’s age?', user: false});
    // this.chatMessages.push({date: new Date(), message: 'Hi', user: true});
    // this.chatMessages.push({date: new Date(), message: 'How can i help you?', user: false});
    var objDiv = document.getElementById('chatContainer');
    objDiv.scrollTop = objDiv.scrollHeight;
  }

  predict() {
    this.inputArray[0][0] = this.age;
    this.inputArray[0][1] = this.breed;
    this.pythonBackendService.predictDiseaseWithSymptoms(this.inputArray)
      .subscribe(res => {
        console.log(this.diseases[res.pred]);
        this.prediction = this.diseases[res.pred];
        this.chatMessages.push({date: new Date(), message: 'Your dog might have '+this.prediction, user: false});
        var objDiv = document.getElementById('chatContainer');
        objDiv.scrollTop = objDiv.scrollHeight;
      });
  }

  sendMessage() {
    this.i += 1;
    if (this.chatMessageInput) {
      this.chatMessages.push({date: new Date(), message: this.chatMessageInput, user: true});
      if (this.i === 1) {
        if (isNumeric(this.chatMessageInput)) {
          this.age = Number(this.chatMessageInput);
          console.log(this.age);
          this.chatMessages.push({date: new Date(), message: 'What is the breed of the dog?', user: false});
        }else {
          this.i -= 1;
          this.chatMessages.push({date: new Date(), message: 'Let’s Start by telling me about your dog’s age?', user: false});
        }
      }else if (this.i === 2) {
        if (this.chatMessageInput.toLowerCase().includes('german') || this.chatMessageInput.toLowerCase().includes('sheppherd')) {
          this.breed = 0;
          this.chatMessages.push({date: new Date(), message: 'Symptoms?', user: false});
        }else if (this.chatMessageInput.toLowerCase().includes('labrador') || this.chatMessageInput.toLowerCase().includes('retriever')) {
          this.breed = 1;
          this.chatMessages.push({date: new Date(), message: 'Symptoms?', user: false});
        }else if (this.chatMessageInput.toLowerCase().includes('mongrel')) {
          this.breed = 2;
          this.chatMessages.push({date: new Date(), message: 'Symptoms?', user: false});
        }else if (this.chatMessageInput.toLowerCase().includes('pomeranian')) {
          this.breed = 3;
          this.chatMessages.push({date: new Date(), message: 'Symptoms?', user: false});
        }else {
          this.i -= 1;
          this.chatMessages.push({date: new Date(), message: 'What is the breed of the dog?', user: false});
        }
      }else {
        const words = this.chatMessageInput.split(' ');
        let totalSymptomCount = 0;
        for (let j = 0; j < this.symptoms.length; j++) {
          if (
            this.symptoms[j].toLowerCase().includes(this.chatMessageInput.toLowerCase()) ||
            this.chatMessageInput.toLowerCase().includes(this.symptoms[j].toLowerCase())
          ) {
            this.inputArray[0][j+2] = 1;
            totalSymptomCount++;
          }
        }
        if (totalSymptomCount > 4) {
          this.predict();
        }else {
          this.i -= 1;
          this.chatMessages.push({date: new Date(), message: 'Can you tell me more about the symptoms?', user: false});
        }
      }
      this.chatMessageInput = '';
    }
    var objDiv = document.getElementById('chatContainer');
    objDiv.scrollTop = objDiv.scrollHeight;
  }

  selectSymtom(symptom: string) {
    this.chatMessageInput += symptom + ' ';
  }
}
