import { Component, OnInit } from '@angular/core';
import {ActivatedRoute} from '@angular/router';
import {PythonBackendService} from '../core/python-backend.service';
import {Food} from "../core/food";

@Component({
  selector: 'app-generated-food-plan',
  templateUrl: './generated-food-plan.page.html',
  styleUrls: ['./generated-food-plan.page.scss'],
})
export class GeneratedFoodPlanPage implements OnInit {
  breed: number;
  weight: number;
  height: number;
  bcs = 1;
  calories = 0;
  selectedCalories = 0;
  public prediction: string;
  public foods: Food[] = [];

  public selectedFoods = '';

  constructor(
    private route: ActivatedRoute,
    private pythonBackendService: PythonBackendService
    ) { }

  ngOnInit() {
    this.breed = Number(this.route.snapshot.paramMap.get('breed'));
    this.weight = Number(this.route.snapshot.paramMap.get('weight'));
    this.height = Number(this.route.snapshot.paramMap.get('height'));

    this.foods.push({calories: 130, name: 'White rice'+' (100g)'});
    this.foods.push({calories: 208, name: 'Salmon'+' (100g)'});
    this.foods.push({calories: 100, name: 'Tuna'+' (100g)'});
    this.foods.push({calories: 41, name: 'Carrot'+' (100g)'});
    this.foods.push({calories: 239, name: 'Chicken'+' (100g)'});
    this.foods.push({calories: 165, name: 'Chicken breast'+' (100g)'});
    this.foods.push({calories: 250, name: 'Beef'+' (100g)'});
    this.foods.push({calories: 242, name: 'Pork'+' (100g)'});
    this.foods.push({calories: 59, name: 'Yoghurt'+' (100g)'});
    this.foods.push({calories: 89, name: 'Banana'+' (100g)'});
    this.foods.push({calories: 30, name: 'Watermelon'+' (100g)'});

    this.pythonBackendService.predictWeight([[this.breed, this.height, this.weight]])
      .subscribe(res => {
        console.log(res);
        if (res.pred === '0') {
          this.prediction = 'Normal weight';
          this.bcs = 1;
        }
        if (res.pred === '1') {
          this.prediction = 'Over weight';
          this.bcs = 0.8;
        }
        if (res.pred === '2') {
          this.prediction = 'Under weight';
          this.bcs = 1.2;
        }
        this.calories = 70*this.weight*this.bcs;
      });
  }

  selectFood(food: Food) {
    if (this.selectedFoods) {
      this.selectedFoods += ' + ' + food.name;
    }else {
      this.selectedFoods += food.name;
    }
    this.selectedCalories += food.calories;
  }
}
