import {Component, ElementRef, OnInit, ViewChild} from '@angular/core';
import {ActivatedRoute} from '@angular/router';
import {PythonBackendService} from '../core/python-backend.service';
import {environment} from '../../environments/environment';
import jsPDF from 'jspdf';
import html2canvas from 'html2canvas';

@Component({
  selector: 'app-skin-disease-report',
  templateUrl: './skin-disease-report.page.html',
  styleUrls: ['./skin-disease-report.page.scss'],
})
export class SkinDiseaseReportPage implements OnInit {
  @ViewChild('reportContent') reportContent: ElementRef;
  disease: string;
  owner: string;
  dog: string;
  age: string;
  baseUrlSkinImageClassification = environment.baseUrlSkinImageClassification;
  comment: number;

  constructor(
    private route: ActivatedRoute,
    private pythonBackendService: PythonBackendService
  ) { }

  ngOnInit() {
    this.disease = this.route.snapshot.paramMap.get('disease');
    this.owner = localStorage.getItem('email');
    this.age = localStorage.getItem('age');
    this.dog = localStorage.getItem('name');

  }

  public openPDF() {
    const doc = new jsPDF();
    doc.text('Disease: '+this.disease, 10, 10);
    doc.text('Owner: '+this.owner, 10, 20);
    doc.text('Dog\'s name: '+this.dog, 10, 30);
    doc.text('Dog\'s age: '+this.age, 10, 40);
    doc.text('Symptoms: '+this.comment, 10, 50);
    var img = new Image();
    img.src = this.baseUrlSkinImageClassification+'/getImage';
    doc.addImage(img, 'png', 10, 60, 100, 100);
    doc.save('report.pdf');
  }

}
