import { Component, OnInit } from '@angular/core';
import {PythonBackendService} from "../core/python-backend.service";
import {FormBuilder, FormGroup} from "@angular/forms";
import {Router} from "@angular/router";

@Component({
  selector: 'app-skin-disease-take-image',
  templateUrl: './skin-disease-take-image.page.html',
  styleUrls: ['./skin-disease-take-image.page.scss'],
})
export class SkinDiseaseTakeImagePage implements OnInit {
  uploadForm: FormGroup;
  imageSrc: any;
  public prediction: string;
  loading = false;

  constructor(
    private pythonBackendService: PythonBackendService,
    private formBuilder: FormBuilder,
    private router: Router
  ) { }

  ngOnInit() {
    this.uploadForm = this.formBuilder.group({
      file: ['']
    });
  }

  onFileSelect(event) {
    if (event.target.files.length > 0) {
      const file = event.target.files[0];
      this.uploadForm.get('file').setValue(file);
      const reader = new FileReader();
      reader.onload = e => this.imageSrc = reader.result;
      reader.readAsDataURL(file);

    }
  }

  onSubmit() {
    const formData = new FormData();
    formData.append('file', this.uploadForm.get('file').value);

    this.loading = true;
    this.pythonBackendService.predictSkinDisease(formData)
      .subscribe(res => {
        console.log(res);
        this.loading = false;
        this.prediction = res;
        this.router.navigate(['/skin-disease-result/'+res.pred]);
      }, error => {
        console.log(error);
      });
  }

}
