import { Injectable } from '@angular/core';
import {environment} from '../environments/environment';
import {HttpClient} from '@angular/common/http';
import {RestCallsService} from './rest-calls.service';
import {Observable} from 'rxjs';
import {LoginDto} from './interfaces/login-dto';
import {UserDto} from './interfaces/user-dto';
import {Dog} from './interfaces/dog';
import {Question} from './interfaces/question';
import {Answer} from './interfaces/answer';

@Injectable({
  providedIn: 'root'
})
export class SpringBackendServiceService {
  baseUrl = environment.baseUrlSpring;

  constructor(
    private httpClient: HttpClient,
    private restCallsService: RestCallsService
  ) { }

  login(login: LoginDto): Observable<any> {
    return this.httpClient.post<any>(`${this.baseUrl}auth/signin`, login);
  }

  signup(userDto: UserDto): Observable<any> {
    return this.httpClient.post<any>(`${this.baseUrl}auth/createAccount`, userDto);
  }

  newDog(dog: Dog): Observable<any> {
    return this.httpClient.post<any>(`${this.baseUrl}dog`, dog, this.restCallsService.getRequestHeaders());
  }

  allDogs() {
    return this.httpClient.get<any>(`${this.baseUrl}dogs`, this.restCallsService.getRequestHeaders());
  }

  newQuestion(question: Question): Observable<any> {
    return this.httpClient.post<any>(`${this.baseUrl}question`, question, this.restCallsService.getRequestHeaders());
  }

  allQuestions() {
    return this.httpClient.get<any>(`${this.baseUrl}questions`, this.restCallsService.getRequestHeaders());
  }

  newAnswer(answer: Answer): Observable<any> {
    return this.httpClient.post<any>(`${this.baseUrl}answer`, answer, this.restCallsService.getRequestHeaders());
  }

  answersByQuestion(id) {
    return this.httpClient.get<any>(`${this.baseUrl}answers/`+id, this.restCallsService.getRequestHeaders());
  }

  allAnswers() {
    return this.httpClient.get<any>(`${this.baseUrl}answers`, this.restCallsService.getRequestHeaders());
  }
}
