package com.sliit.bestbark.controller;

import com.sliit.bestbark.dto.AuthenticationRequest;
import com.sliit.bestbark.dto.UserDto;
import com.sliit.bestbark.exception.ResourceNotFoundException;
import com.sliit.bestbark.model.UserModel;
import com.sliit.bestbark.model.UserRepository;
import com.sliit.bestbark.security.JwtTokenProvider;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.authentication.BadCredentialsException;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.*;

@RestController
@RequestMapping("/auth")
public class AuthController {

    @Autowired
    private UserRepository userRepository;

    @Autowired
    AuthenticationManager authenticationManager;

    @Autowired
    JwtTokenProvider jwtTokenProvider;

    @Autowired
    PasswordEncoder passwordEncoder;

    @PostMapping("/signin")
    public ResponseEntity signin(@RequestBody AuthenticationRequest data) {
        try {
            String username = data.getUsername();
            authenticationManager.authenticate(new UsernamePasswordAuthenticationToken(username, data.getPassword()));
            String token = jwtTokenProvider.createToken(username, userRepository.findByUsername(username).orElseThrow(() -> new ResourceNotFoundException("User", "Username", username)).getRoles());

            Map<Object, Object> model = new HashMap<>();
            model.put("username", username);
            model.put("token", token);
            return ResponseEntity.ok(model);
        }catch (AuthenticationException e){
            throw new BadCredentialsException("Invalid username/password supplied");
        }
    }


    @PostMapping("/createAccount")
    public ResponseEntity createAdminAccount(@RequestBody UserDto userDto){
        List<UserModel> users = userRepository.findUsersByUsername(userDto.getUsername());
        if (users.size() == 0){
            UserModel user = new UserModel(userDto.getUsername(), passwordEncoder.encode(userDto.getPassword()), Arrays.asList( "ROLE_ADMIN", "ROLE_INSTITUTE", "ROLE_USER"));
            user = userRepository.save(user);
            userDto.setId(user.getUser_id());
            return ResponseEntity.ok(userDto);
        }else {
            return ResponseEntity.ok(userDto);
        }
    }


}
