package com.sliit.bestbark.controller;

import com.sliit.bestbark.dto.QuestionDto;
import com.sliit.bestbark.exception.ResourceNotFoundException;
import com.sliit.bestbark.model.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.annotation.AuthenticationPrincipal;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;

@RestController
public class MainController {

    @Autowired
    UserRepository userRepository;

    @Autowired
    DogRepository dogRepository;

    @Autowired
    QuestionRepository questionRepository;

    @Autowired
    AnswerRepository answerRepository;

    @PostMapping("/dog")
    public Dog newDog(@RequestBody Dog dog, @AuthenticationPrincipal UserDetails userDetails) {
        UserModel userModel = userRepository.findByUsername(userDetails.getUsername()).orElseThrow(() -> new ResourceNotFoundException("User", "username", userDetails.getUsername()));
        dog.setUser(userModel);
        return dogRepository.save(dog);
    }

    @GetMapping("/dogs")
    public List<Dog> allDogs(@AuthenticationPrincipal UserDetails userDetails) {
        UserModel userModel = userRepository.findByUsername(userDetails.getUsername()).orElseThrow(() -> new ResourceNotFoundException("User", "username", userDetails.getUsername()));
        return dogRepository.findByUser(userModel);
    }

    @PostMapping("/question")
    public Question newQuestion(@RequestBody Question question, @AuthenticationPrincipal UserDetails userDetails) {
        UserModel userModel = userRepository.findByUsername(userDetails.getUsername()).orElseThrow(() ->
                new ResourceNotFoundException("User", "username", userDetails.getUsername()));
        return questionRepository.save(question);
    }

    @PostMapping("/answer")
    public Answer newAnswer(@RequestBody Answer answer, @AuthenticationPrincipal UserDetails userDetails) {
        UserModel userModel = userRepository.findByUsername(userDetails.getUsername()).orElseThrow(() ->
                new ResourceNotFoundException("User", "username", userDetails.getUsername()));
        return answerRepository.save(answer);
    }

    @GetMapping("/questions")
    public List<QuestionDto> allQuestions() {
        List<QuestionDto> questionDtos = new ArrayList<>();
        List<Question> questions = questionRepository.findAll();
        for (int i = 0; i < questions.size(); i++) {
            List<Answer> answers = answersByQuestion(questions.get(i).getId());
            questionDtos.add(new QuestionDto(
                    questions.get(i).getId(),
                    questions.get(i).getTitle(),
                    questions.get(i).getContent(),
                    questions.get(i).getVotes(),
                    answers
            ));
        }
        return questionDtos;
    }

    @GetMapping("/answers/{questionId}")
    public List<Answer> answersByQuestion(@PathVariable Long questionId) {
        Question question = questionRepository.findById(questionId).orElseThrow(() ->
                new ResourceNotFoundException("Question", "id", questionId));
        return answerRepository.findByQuestion(question);
    }

    @GetMapping("/answers")
    public List<Answer> allAnswers() {
        return answerRepository.findAll();
    }

}
