package com.sliit.bestbark.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.userdetails.UserDetails;

import javax.persistence.*;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import static java.util.stream.Collectors.toList;

@Entity
@Table(name="users")
public class UserModel implements UserDetails {

    @Id
    @GeneratedValue
    private Long user_id;
    private int otp;
    private String username;

    private String password;
    private String fname;
    private String lname;
    private String email_address;
    private String phone_no;
    private String user_role;
    private String prof_img_url;

    private boolean enabled = true;

    @ElementCollection(fetch = FetchType.EAGER)
    private List<String> roles = new ArrayList<>();
    private int emailOtp;

    @JsonIgnore
    @Override
    public Collection<? extends GrantedAuthority> getAuthorities() {
        return this.roles.stream().map(SimpleGrantedAuthority::new).collect(toList());
    }

    public UserModel() {
    }

    public UserModel(String username, String password, List<String> roles) {
        this.username = username;
        this.password = password;
        this.roles = roles;
    }

    public UserModel(Long user_id) {
        this.user_id = user_id;
    }

    public UserModel(String username, String password, boolean enabled, List<String> roles) {
        this.username = username;
        this.password = password;
        this.enabled = enabled;
        this.roles = roles;
    }

    public Long getUser_id() {
        return user_id;
    }
    public String getUser_name() {
        return username;
    }
    public String getPassword() {
        return password;
    }
    public String getUser_role() {
        return user_role;
    }
    public void setUser_id(Long user_id) {
        this.user_id = user_id;
    }
    public void setUser_name(String user_name) {
        this.username = user_name;
    }
    public void setPassword(String password) {
        this.password = password;
    }
    public void setUser_role(String user_role) {
        this.user_role = user_role;
    }
    public String getUsername() {
        return username;
    }

    @Override
    public boolean isAccountNonExpired() {
        return true;
    }

    @Override
    public boolean isAccountNonLocked() {
        return true;
    }

    @Override
    public boolean isCredentialsNonExpired() {
        return true;
    }

    @Override
    public boolean isEnabled() {
        return enabled;
    }

    public void setUsername(String username) {
        this.username = username;
    }
    public String getFname() {
        return fname;
    }
    public void setFname(String fname) {
        this.fname = fname;
    }
    public String getLname() {
        return lname;
    }
    public void setLname(String lname) {
        this.lname = lname;
    }
    public String getEmail_address() {
        return email_address;
    }
    public void setEmail_address(String email_address) {
        this.email_address = email_address;
    }
    public String getPhone_no() {
        return phone_no;
    }
    public void setPhone_no(String phone_no) {
        this.phone_no = phone_no;
    }

    public void setEnabled(boolean enabled) {
        this.enabled = enabled;
    }

    public List<String> getRoles() {
        return roles;
    }

    public void setRoles(List<String> roles) {
        this.roles = roles;
    }

    public int getOtp() {
        return otp;
    }

    public void setOtp(int otp) {
        this.otp = otp;
    }

    public String getProf_img_url() {
        return prof_img_url;
    }

    public void setProf_img_url(String prof_img_url) {
        this.prof_img_url = prof_img_url;
    }

    public void setEmailOtp(int emailOtp) {
        this.emailOtp = emailOtp;
    }

    public int getEmailOtp() {
        return emailOtp;
    }
}
